@@ -2,8 +2,8 @@ package POE::Wheel::ListenAccept;
 
 use strict;
 
-use vars qw($VERSION);
-$VERSION = '1.289'; # NOTE - Should be #.### (three decimal places)
+use vars qw($VERSION @ISA);
+$VERSION = '1.312'; # NOTE - Should be #.### (three decimal places)
 
 use Carp qw( croak carp );
 use Symbol qw( gensym );
@@ -11,7 +11,7 @@ use Symbol qw( gensym );
 use POSIX qw(:fcntl_h);
 use Errno qw(EWOULDBLOCK);
 use POE qw( Wheel );
-use base qw(POE::Wheel);
+push @ISA, qw(POE::Wheel);
 
 sub SELF_HANDLE       () { 0 }
 sub SELF_EVENT_ACCEPT () { 1 }
