@@ -8,8 +8,8 @@ package PoeBuildInfo;
 use strict;
 
 use Exporter;
-use base qw(Exporter);
-use vars qw(@EXPORT_OK);
+use vars qw(@ISA @EXPORT_OK);
+push @ISA, qw(Exporter);
 
 @EXPORT_OK = qw(
   TEST_FILES
@@ -17,7 +17,6 @@ use vars qw(@EXPORT_OK);
   CORE_REQUIREMENTS
   DIST_ABSTRACT
   DIST_AUTHOR
-  RECOMMENDED_TIME_HIRES
   CONFIG_REQUIREMENTS
   REPOSITORY
   HOMEPAGE
@@ -25,9 +24,7 @@ use vars qw(@EXPORT_OK);
 
 
 sub CONFIG_REQUIREMENTS () {
-  (
-    "POE::Test::Loops"  => '1.035',
-  )
+  ("POE::Test::Loops"  => '1.312')
 }
 
 sub CORE_REQUIREMENTS () {
@@ -36,11 +33,13 @@ sub CORE_REQUIREMENTS () {
     "Errno"             => 1.09,
     "Exporter"          => 0,
     "File::Spec"        => 0.87,
+    "IO"                => 1.24,  # MSWin32 blocking(0)
     "IO::Handle"        => 1.27,
     "POSIX"             => 1.02,
     "Socket"            => 1.7,
-    "Test::Harness"     => 2.26,
     "Storable"          => 2.16,
+    "Test::Harness"     => 2.26,
+    "Time::HiRes"       => 1.59,
     (
       ($^O eq "MSWin32")
       ? (
@@ -58,32 +57,36 @@ sub CORE_REQUIREMENTS () {
   )
 }
 
-sub RECOMMENDED_TIME_HIRES () {
-  ( "Time::HiRes" => 1.59 )
-}
-
 sub DIST_AUTHOR () {
   ( 'Rocco Caputo <rcaputo@cpan.org>' )
 }
 
 sub DIST_ABSTRACT () {
-  ( 'A portable networking and multitasking framework.' )
+  ( 'Portable, event-loop agnostic eventy networking and multitasking.' )
 }
 
 sub CLEAN_FILES () {
   my @clean_files = qw(
+    */*/*/*/*~
+    */*/*/*~
+    */*/*/*~
+    */*/*~
+    */*~
+    *~
+    META.yml
+    Makefile.old
     bingos-followtail
     coverage.report
     poe_report.xml
     run_network_tests
-    test-output.err
     t/20_resources/10_perl
     t/20_resources/10_perl/*
     t/20_resources/20_xs
     t/20_resources/20_xs/*
-    t/30_loops/*/*
-    t/30_loops/*
     t/30_loops
+    t/30_loops/*
+    t/30_loops/*/*
+    test-output.err
   );
   "@clean_files";
 }
@@ -98,11 +101,11 @@ sub TEST_FILES () {
 }
 
 sub REPOSITORY () {
-  ( 'https://poe.svn.sourceforge.net/svnroot/poe/trunk' )
+  'https://github.com/rcaputo/poe'
 }
 
 sub HOMEPAGE () {
-  ( 'http://poe.perl.org/' )
+  'http://poe.perl.org/'
 }
 
 1;
